==> unicore-xuudb-1.3.2-2.src.tar.gz: xuudb-common/src/main/java/de/fzj/unicore/xuudb/Configuration.java <==
/*********************************************************************************
 * Copyright (c) 2006 Forschungszentrum Juelich GmbH 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Forschungszentrum Juelich GmbH nor the names of its 
 * contributors may be used to endorse or promote products derived from this 
 * software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************************/
 

package de.fzj.unicore.xuudb;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

import org.apache.log4j.Logger;

public class Configuration extends Properties {

	private static final long serialVersionUID = 1L;
    public static final String XUUDBFILE = "xuudb_data_file";
    public static final String HTTPPORT = "xuudb_http_port";
    public static final String HTTPHOST = "xuudb_http_host";
    public static final String GCID = "xuudb_gcid";
    public static final String USESSL = "xuudb_use_ssl";
    public static final String KEYSTORE = "xuudb_keystore_file";
    public static final String KEYSTOREPASSWORD = "xuudb_keystore_password";
    public static final String KEYSTORETYPE = "xuudb_keystore_type";
    public static final String TRUSTSTORE = "xuudb_truststore_file";
    public static final String TRUSTSTOREPASSWORD = "xuudb_truststore_password";
    public static final String TRUSTSTORETYPE = "xuudb_truststore_type";
    
    /**
     * type of XUUDB: "dn" checks DNs only, while "normal" checks the certficate
     */
    public static final String XUUDBTYPE = "xuudb_type";

	private static final Logger logger = Logger.getLogger("XUUDB");
	
	public static Logger getLogger() { return logger; }
	
	public static Logger getLogger(Class<?> clazz) { return Logger.getLogger("XUUDB."+clazz.getSimpleName()); }
	
	private static Configuration instance = null;
	
	/**
	 * creates a Configuration instance from a Properties instance.
	 * @param prop has to contain some of the static final keys above 
	 * @return
	 */
	public static Configuration createConfiguration(Properties prop) {
		if(prop == null) {return null;}
		if (instance == null) {
			instance = new Configuration(prop);
		}
		return instance;
	}
	
	
	
	
	
	/**
	 * creates a Configuration instance from Properties-file - like created
	 * with method Configuration.createDefaultServer oder method Configuration.createDefaultClient
	 * @param configFile
	 * @return
	 */
	public static Configuration createConfiguration(File configFile) {
		if(configFile == null) { return null; }
		if (instance == null) {
			try {
				instance = new Configuration(configFile);
			} catch (IOException e) {
				System.out.println("No configuration found at: " + configFile.getPath());
				System.out.println("*** Create a default configuration with   ./init ***");
				return null;
			}
		}
		return instance;
	}
	
	
	
	
	
	
	public Configuration(Properties p) {
		super(p);
	}
	
	
	
	
	
	
	private Configuration(File config) throws IOException {
		this.readConfigFile(config);
		logger.info("Loaded Configuration from file: " + config.getPath());
	}
	
	
	private void readConfigFile(File config) throws IOException {
		if (!config.exists()) {
			logger.error("Configuration file does not exist: "	+ config.getPath());
			throw new IOException();
		}
		this.load(new FileInputStream(config));
	}


	
	
	
	
	public static void createDefaultServer() {
		File def_configDir = new File("conf");
		File def_configFile = new File("conf/xuudb_server.conf");
		File def_xuudbFile = new File("data/UnicoreUserDB.data");
		if(def_configFile.exists()) {
			System.out.println("Config file already exists! Delete dir "+
					def_configFile+" first.");
			return;
		}
		try {
			if(!def_configDir.mkdirs())
				System.out.println("Cannot create default config directory: " + def_configDir);
			else if(!def_configFile.createNewFile())
				System.out.println("Cannot create default config file: " + def_configFile);
		} catch (IOException e) {
			System.out.println("Error while init def values: " + e.getMessage());
			return;
		}
		Properties newone = new Properties();
		//set default properties
		newone.setProperty(Configuration.XUUDBFILE, def_xuudbFile.getPath());
        newone.setProperty(Configuration.HTTPPORT, "34463");
        newone.setProperty(Configuration.USESSL, "false");
        newone.setProperty(Configuration.KEYSTORE, "path/to/keystore/file");
        newone.setProperty(Configuration.KEYSTORETYPE, "JKS");
        newone.setProperty(Configuration.KEYSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.TRUSTSTORE, "path/to/truststore/file");
        newone.setProperty(Configuration.TRUSTSTORETYPE, "JKS");
        newone.setProperty(Configuration.TRUSTSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.XUUDBTYPE, "normal");
        try {
			newone.store(new FileOutputStream(def_configFile), "Default generated configfile");
		} catch (Exception e) {
			logger.info("Cannot write to configfile: " + def_configFile.getAbsolutePath());
			return;
		}

		System.out.println("Created:\n" + 
				def_configFile.getPath() + "\n");
	}

	
	
	
	
	
	public static void createDefaultClient() {
		File def_configDir = new File("conf");
		File def_configFile = new File("conf/xuudb_client.conf");
		if(def_configFile.exists()) {
			System.out.println("Config file already exists! Delete dir "+
					def_configFile+" first.");
			return;
		}
		try {
			if(!def_configDir.mkdirs())
				System.out.println("Cannot create default config directory: " + def_configDir);
			else if(!def_configFile.createNewFile())
				System.out.println("Cannot create default config file: " + def_configFile);
		} catch (IOException e) {
			System.out.println("Error while init def values: " + e.getMessage());
			return;
		}
		
		Properties newone = new Properties();
		//set default properties
		newone.setProperty(Configuration.HTTPPORT, "34463");
        newone.setProperty(Configuration.HTTPHOST, "http://localhost");
        newone.setProperty(Configuration.USESSL, "false");
        newone.setProperty(Configuration.KEYSTORE, "path/to/keystore/file");
        newone.setProperty(Configuration.KEYSTORETYPE, "JKS");
        newone.setProperty(Configuration.KEYSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.TRUSTSTORE, "path/to/truststore/file");
        newone.setProperty(Configuration.TRUSTSTORETYPE, "JKS");
        newone.setProperty(Configuration.TRUSTSTOREPASSWORD, "*****");
        
        try {
			newone.store(new FileOutputStream(def_configFile), "Default generated configfile");
		} catch (Exception e) {
			logger.info("Cannot write to configfile: " + def_configFile.getAbsolutePath());
			return;
		}
		System.out.println("Created:\n" + 
				def_configFile.getPath() + "\n");
	}

	
	
	
}

==> unicore-xuudb-1.3.2-4.src.tar.gz: xuudb-common/src/main/java/de/fzj/unicore/xuudb/Configuration.java <==
/*********************************************************************************
 * Copyright (c) 2006 Forschungszentrum Juelich GmbH 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Forschungszentrum Juelich GmbH nor the names of its 
 * contributors may be used to endorse or promote products derived from this 
 * software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************************/
 

package de.fzj.unicore.xuudb;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

import org.apache.log4j.Logger;

public class Configuration extends Properties {

	private static final long serialVersionUID = 1L;
    public static final String XUUDBFILE = "xuudb_data_file";
    public static final String HTTPPORT = "xuudb_http_port";
    public static final String HTTPHOST = "xuudb_http_host";
    public static final String GCID = "xuudb_gcid";
    public static final String USESSL = "xuudb_use_ssl";
    public static final String KEYSTORE = "xuudb_keystore_file";
    public static final String KEYSTOREPASSWORD = "xuudb_keystore_password";
    public static final String KEYSTORETYPE = "xuudb_keystore_type";
    public static final String TRUSTSTORE = "xuudb_truststore_file";
    public static final String TRUSTSTOREPASSWORD = "xuudb_truststore_password";
    public static final String TRUSTSTORETYPE = "xuudb_truststore_type";
    
    /**
     * type of XUUDB: "dn" checks DNs only, while "normal" checks the certficate
     */
    public static final String XUUDBTYPE = "xuudb_type";

	private static final Logger logger = Logger.getLogger("XUUDB");
	
	public static Logger getLogger() { return logger; }
	
	public static Logger getLogger(Class<?> clazz) { return Logger.getLogger("XUUDB."+clazz.getSimpleName()); }
	
	private static Configuration instance = null;
	
	/**
	 * creates a Configuration instance from a Properties instance.
	 * @param prop has to contain some of the static final keys above 
	 * @return
	 */
	public static Configuration createConfiguration(Properties prop) {
		if(prop == null) {return null;}
		if (instance == null) {
			instance = new Configuration(prop);
		}
		return instance;
	}
	
	
	
	
	
	/**
	 * creates a Configuration instance from Properties-file - like created
	 * with method Configuration.createDefaultServer oder method Configuration.createDefaultClient
	 * @param configFile
	 * @return
	 */
	public static Configuration createConfiguration(File configFile) {
		if(configFile == null) { return null; }
		if (instance == null) {
			try {
				instance = new Configuration(configFile);
			} catch (IOException e) {
				System.out.println("No configuration found at: " + configFile.getPath());
				System.out.println("*** Create a default configuration with   ./init ***");
				return null;
			}
		}
		return instance;
	}
	
	
	
	
	
	
	public Configuration(Properties p) {
		super(p);
	}
	
	
	
	
	
	
	private Configuration(File config) throws IOException {
		this.readConfigFile(config);
		logger.info("Loaded Configuration from file: " + config.getPath());
	}
	
	
	private void readConfigFile(File config) throws IOException {
		if (!config.exists()) {
			logger.error("Configuration file does not exist: "	+ config.getPath());
			throw new IOException();
		}
		FileInputStream istream=new FileInputStream(config);
		try{
			this.load(istream);
		}
		finally{
			istream.close();
		}
	}


	
	
	
	
	public static void createDefaultServer() {
		File def_configDir = new File("conf");
		File def_configFile = new File("conf/xuudb_server.conf");
		File def_xuudbFile = new File("data/UnicoreUserDB.data");
		if(def_configFile.exists()) {
			System.out.println("Config file already exists! Delete dir "+
					def_configFile+" first.");
			return;
		}
		try {
			if(!def_configDir.mkdirs())
				System.out.println("Cannot create default config directory: " + def_configDir);
			else if(!def_configFile.createNewFile())
				System.out.println("Cannot create default config file: " + def_configFile);
		} catch (IOException e) {
			System.out.println("Error while init def values: " + e.getMessage());
			return;
		}
		Properties newone = new Properties();
		//set default properties
		newone.setProperty(Configuration.XUUDBFILE, def_xuudbFile.getPath());
        newone.setProperty(Configuration.HTTPPORT, "34463");
        newone.setProperty(Configuration.USESSL, "false");
        newone.setProperty(Configuration.KEYSTORE, "path/to/keystore/file");
        newone.setProperty(Configuration.KEYSTORETYPE, "JKS");
        newone.setProperty(Configuration.KEYSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.TRUSTSTORE, "path/to/truststore/file");
        newone.setProperty(Configuration.TRUSTSTORETYPE, "JKS");
        newone.setProperty(Configuration.TRUSTSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.XUUDBTYPE, "normal");
        try {
			FileOutputStream ostream=new FileOutputStream(def_configFile);
			try{
				newone.store(ostream, "Default generated configfile");
			}
			finally {
				ostream.close();
			}
		} catch (Exception e) {
			logger.info("Cannot write to configfile: " + def_configFile.getAbsolutePath());
			return;
		}

		System.out.println("Created:\n" + 
				def_configFile.getPath() + "\n");
	}

	
	
	
	
	
	public static void createDefaultClient() {
		File def_configDir = new File("conf");
		File def_configFile = new File("conf/xuudb_client.conf");
		if(def_configFile.exists()) {
			System.out.println("Config file already exists! Delete dir "+
					def_configFile+" first.");
			return;
		}
		try {
			if(!def_configDir.mkdirs())
				System.out.println("Cannot create default config directory: " + def_configDir);
			else if(!def_configFile.createNewFile())
				System.out.println("Cannot create default config file: " + def_configFile);
		} catch (IOException e) {
			System.out.println("Error while init def values: " + e.getMessage());
			return;
		}
		
		Properties newone = new Properties();
		//set default properties
		newone.setProperty(Configuration.HTTPPORT, "34463");
        newone.setProperty(Configuration.HTTPHOST, "http://localhost");
        newone.setProperty(Configuration.USESSL, "false");
        newone.setProperty(Configuration.KEYSTORE, "path/to/keystore/file");
        newone.setProperty(Configuration.KEYSTORETYPE, "JKS");
        newone.setProperty(Configuration.KEYSTOREPASSWORD, "*****");
        newone.setProperty(Configuration.TRUSTSTORE, "path/to/truststore/file");
        newone.setProperty(Configuration.TRUSTSTORETYPE, "JKS");
        newone.setProperty(Configuration.TRUSTSTOREPASSWORD, "*****");

        try {
			FileOutputStream ostream=new FileOutputStream(def_configFile);
			try{
				newone.store(ostream, "Default generated configfile");
			}
			finally {
				ostream.close();
			}
		} catch (Exception e) {
			logger.info("Cannot write to configfile: " + def_configFile.getAbsolutePath());
			return;
		}
		System.out.println("Created:\n" + 
				def_configFile.getPath() + "\n");
	}

	
	
	
}
